@@ -26,6 +26,12 @@ function app_server(port){
   server.serve(__dirname,port);
 }
 
+function app_web(port){
+
+}
+function app_api(){}
+function app_deploy(){}
+
 program
   .version('1.4.1')
   .option('-i, init', 'init project',app_init)
